# krazy-utils

I am a beginner in programming and have recently started programming in python. krazy-utils is a simple package containing following functions I use frequently. I just wrote some of them so that I dont forget how to write them ;p

Thought of sharing it as it may help beginners like me:

1. Basic pandas operations on columns like retaining columns passed as list, renaming columns passed as dictionery, etc. It contains one line pandas command to retain columns given to this function. For me, it was easier to do it throuh one word functin rather then half screen length command :p

2. Read and write from CSV.

3. Import from multiple excel files if a directory is given.

4. Getting file list of entire tree under a given directory.

5. Excel to pdf converter

6. Date converter: accepts date (based on d/m/y sequence) written as string with / or - as separators and convert to proper date. 

7. Timekeeper to keep time during runtimes... print command inbuilt.

8. OCR function using pytesseract. For this to work you will need pytesseract and Tesseract installed.

9. Some other small basic stuff.

10. A simple tkinter frontend ready for use with app label, button bar frame and content frame.

I havent explained them a lot here as the code itself is simple and self explanatory.

Suggestions are most welcome.